PyXMake Developer Guide: PyXMake.Plugin.__git Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.Plugin.__git Namespace Reference

## Functions
| setup ()
| update ()
| main (**kwargs)

## Detailed Description

    GIT configuration and management assistance wrapper.

    @note:
    Created on 08.08.2022

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.Plugin.__git.main | ( | ** | kwargs | ) |

    Main command line parser.

Definition at line 130 of file __git.py.

## ◆ setup()

PyXMake.Plugin.__git.setup | ( |  | ) |

    GIT configuration helper interface

Definition at line 32 of file __git.py.

## ◆ update()

PyXMake.Plugin.__git.update | ( |  | ) |

    GIT pull command with recursive submodule and LFS support

Definition at line 73 of file __git.py.